@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention Management Console
 #  module: ipchange
@@ -35,7 +34,7 @@
 # <https://www.gnu.org/licenses/>.
 
 import ipaddress
-from typing import Dict, Union
+from urllib.parse import urlparse
 
 from ldap.filter import filter_format
 
@@ -55,7 +54,7 @@ univention.admin.modules.update()
 class Instance(Base):
 
     @simple_response
-    def change(self, role: str, ip: str, netmask: str, oldip: Union[str, None] = None) -> Dict:
+    def change(self, role: str, ip: str, netmask: str, oldip: str | None = None) -> dict:
         """
         Return a dict with all necessary values for ipchange read from the current
         status of the system.
@@ -119,7 +118,8 @@ class Instance(Base):
         # Change ucs-sso entry
         # FIXME: this should be done for UCS-in-AD domains as well!
         ucr.load()
-        sso_fqdn = ucr.get('keycloak/server/sso/fqdn').lower()
+        sso_uri = ucr.get('ucs/server/sso/uri').lower()
+        sso_fqdn = urlparse(sso_uri).netloc
         if ucr.is_true('keycloak/server/sso/autoregistraton', True) and sso_fqdn:
             fmodule = univention.admin.modules.get('dns/forward_zone')
             forwardobjects = univention.admin.modules.lookup(fmodule, None, lo, scope='sub', superordinate=None, filter=None)
